﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Diagnostics;
using System.Linq;
using System.Runtime.InteropServices;
using System.Text;
using System.Windows.Forms;
using DocumentFormat.OpenXml.Packaging;
using DocumentFormat.OpenXml.Validation;
using DocumentFormat.OpenXml.Spreadsheet;
using DocumentFormat.OpenXml;

namespace MultiTasking
{
    partial class Form3
    {
        // Structure contain information about low-level keyboard input event
        [StructLayout(LayoutKind.Sequential)]
        private struct KBDLLHOOKSTRUCT
        {
            public Keys key;
            public int scanCode;
            public int flags;
            public int time;
            public IntPtr extra;
        }

        //System level functions to be used for hook and unhook keyboard input
        private delegate IntPtr LowLevelKeyboardProc(int nCode, IntPtr wParam, IntPtr lParam);
        [DllImport("user32.dll", CharSet = CharSet.Auto, SetLastError = true)]
        private static extern IntPtr SetWindowsHookEx(int id, LowLevelKeyboardProc callback, IntPtr hMod, uint dwThreadId);
        [DllImport("user32.dll", CharSet = CharSet.Auto, SetLastError = true)]
        private static extern bool UnhookWindowsHookEx(IntPtr hook);
        [DllImport("user32.dll", CharSet = CharSet.Auto, SetLastError = true)]
        private static extern IntPtr CallNextHookEx(IntPtr hook, int nCode, IntPtr wp, IntPtr lp);
        [DllImport("kernel32.dll", CharSet = CharSet.Auto, SetLastError = true)]
        private static extern IntPtr GetModuleHandle(string name);
        [DllImport("user32.dll", CharSet = CharSet.Auto)]
        private static extern short GetAsyncKeyState(Keys key);


        //Declaring Global objects
        private IntPtr ptrHook;
        private LowLevelKeyboardProc objKeyboardProcess;

        public static List<Keys> PermittedKeys = new List<Keys>(
          new Keys[]
        { // Alphanumeric keys.
          Keys.A, Keys.B, Keys.C, Keys.D, Keys.E, Keys.F, Keys.G, Keys.H,
          Keys.I, Keys.J, Keys.K, Keys.L, Keys.M, Keys.N, Keys.O, Keys.P,
          Keys.Q, Keys.R, Keys.S, Keys.T, Keys.U, Keys.V, Keys.W, Keys.X,
          Keys.Y, Keys.Z,
          Keys.D0, Keys.D1, Keys.D2, Keys.D3, Keys.D4, Keys.D5, Keys.D6,
          Keys.D7, Keys.D8, Keys.D9, Keys.Delete, Keys.Back,
          Keys.NumPad0, Keys.NumPad1, Keys.NumPad2, Keys.NumPad3, Keys.NumPad4,
          Keys.NumPad5, Keys.NumPad6, Keys.NumPad7, Keys.NumPad8, Keys.NumPad9,
          Keys.Control,Keys.C,Keys.LControlKey,Keys.V/*,
          Keys.Decimal,

          // Punctuation and other keys
          Keys.Enter, Keys.Space,
          Keys.Subtract, Keys.Add, Keys.Divide, Keys.Multiply,
          Keys.OemOpenBrackets, Keys.OemCloseBrackets, Keys.Oemcomma, Keys.OemPeriod,
          Keys.Oemplus, Keys.OemMinus, Keys.OemQuestion, Keys.OemQuotes,
          Keys.OemSemicolon, Keys.Oemtilde, Keys.OemBackslash,

          // Editing keys
          Keys.Delete, Keys.Back,
          Keys.LShiftKey, Keys.RShiftKey, Keys.Shift, Keys.ShiftKey,

          // Navigation keys
          Keys.Up, Keys.Down, Keys.Left, Keys.Right, Keys.PageUp, Keys.PageDown,
          Keys.Home, Keys.End,*/
      });
        private IntPtr captureKey(int nCode, IntPtr wp, IntPtr lp)
        {
            if (nCode >= 0)
            {
                KBDLLHOOKSTRUCT objKeyInfo = (KBDLLHOOKSTRUCT)Marshal.PtrToStructure(lp, typeof(KBDLLHOOKSTRUCT));

                /*if (objKeyInfo.key == Keys.RWin || objKeyInfo.key == Keys.LWin) // Disabling Windows keys
                {
                    return (IntPtr)1;
                }*/
                // Reject any key that's not on our list.
                if (!PermittedKeys.Contains(objKeyInfo.key))
                    return (IntPtr)1;
            }
            return CallNextHookEx(ptrHook, nCode, wp, lp);
        }

        public static string GetCellValue(string fileName, string sheetName, string addressName)
        {
            string value = null;

            // Open the spreadsheet document for read-only access.
            using (SpreadsheetDocument document =
                SpreadsheetDocument.Open(fileName, false))
            {
                // Retrieve a reference to the workbook part.
                WorkbookPart wbPart = document.WorkbookPart;

                // Find the sheet with the supplied name, and then use that 
                // Sheet object to retrieve a reference to the first worksheet.
                Sheet theSheet = wbPart.Workbook.Descendants<Sheet>().
                  Where(s => s.Name == sheetName).FirstOrDefault();

                // Throw an exception if there is no sheet.
                if (theSheet == null)
                {
                    throw new ArgumentException("sheetName");
                }

                // Retrieve a reference to the worksheet part.
                WorksheetPart wsPart =
                    (WorksheetPart)(wbPart.GetPartById(theSheet.Id));

                //Random address generator
                //int rowCnt = wsPart.Worksheet.Desc
                //int id = new Random().Next(1,7);
                //addressName = "A" + id;
                //Console.WriteLine(addressName);

                // Use its Worksheet property to get a reference to the cell 
                // whose address matches the address you supplied.
                Cell theCell = wsPart.Worksheet.Descendants<Cell>().
                  Where(c => c.CellReference == addressName).FirstOrDefault();

                // If the cell does not exist, return an empty string.
                if (theCell != null)
                {
                    value = theCell.InnerText;

                    // If the cell represents an integer number, you are done. 
                    // For dates, this code returns the serialized value that 
                    // represents the date. The code handles strings and 
                    // Booleans individually. For shared strings, the code 
                    // looks up the corresponding value in the shared string 
                    // table. For Booleans, the code converts the value into 
                    // the words TRUE or FALSE.
                    if (theCell.DataType != null)
                    {
                        switch (theCell.DataType.Value)
                        {
                            case CellValues.SharedString:

                                // For shared strings, look up the value in the
                                // shared strings table.
                                var stringTable =
                                    wbPart.GetPartsOfType<SharedStringTablePart>()
                                    .FirstOrDefault();

                                // If the shared string table is missing, something 
                                // is wrong. Return the index that is in
                                // the cell. Otherwise, look up the correct text in 
                                // the table.
                                if (stringTable != null)
                                {
                                    value = stringTable.SharedStringTable.ElementAt(int.Parse(value)).InnerText;
                                    //stringTable.SharedStringTable.ElementAt(int.Parse(value)).InnerText = "salary";
                                }
                                break;

                            case CellValues.Boolean:
                                switch (value)
                                {
                                    case "0":
                                        value = "FALSE";
                                        break;
                                    default:
                                        value = "TRUE";
                                        break;
                                }
                                break;
                        }
                    }
                }
            }
            return value;
        }
        private String Number2String(int number, bool isCaps)
        {
            if (number < 26)
            {
                Char c = (Char)((isCaps ? 65 : 97) + (number - 0));
                Console.WriteLine(c.ToString());
                return c.ToString();
            }
            else
            {
                Char c = (Char)((isCaps ? 65 : 97) + (number - 26 - 0));
                string s = "A" + c.ToString();
                Console.WriteLine(s);
                return s;
            }
        }
        private string[] JoinData(string s1, string s2, string s3, string s4,
            string s5, string s6, string s7, string s8, string s9, string s10,
            double[] t1, double[] t2, int v)
        {
            string[] s = new string[31];
            s[0] = s1;
            s[1] = s2;
            s[2] = s3;
            s[3] = s4;
            s[4] = s5;
            s[5] = s6;
            s[6] = s7;
            s[7] = s8;
            s[8] = s9;
            s[9] = s10;
            for (int i = 0; i < t1.Length; i++)
            {
                s[10 + i] = Convert.ToString(t1[i]);
                Console.WriteLine(s[10 + i]);
            }
            for (int i = 0; i < t2.Length; i++)
            {
                s[10 + t1.Length + i] = Convert.ToString(t2[i]);
                Console.WriteLine(s[10 + t1.Length + i]);
            }
            s[30] = v.ToString();
            return s;
        }
        public void InsertText(string docName, string sheetName, string column, string[] data)
        {
            // Open the document for editing.
            using (SpreadsheetDocument spreadSheet = SpreadsheetDocument.Open(docName, true))
            {
                // Get the SharedStringTablePart. If it does not exist, create a new one.
                SharedStringTablePart shareStringPart;
                if (spreadSheet.WorkbookPart.GetPartsOfType<SharedStringTablePart>().Count() > 0)
                {
                    shareStringPart = spreadSheet.WorkbookPart.GetPartsOfType<SharedStringTablePart>().First();
                }
                else
                {
                    shareStringPart = spreadSheet.WorkbookPart.AddNewPart<SharedStringTablePart>();
                }

                // Insert the text into the SharedStringTablePart.
                //int index = InsertSharedStringItem(text, shareStringPart);
                int[] dindex = new int[data.Length];
                for (int i = 0; i < data.Length; i++)
                {
                    dindex[i] = InsertSharedStringItem(data[i], shareStringPart);
                }

                // Retrieve a reference to the workbook part.
                WorkbookPart wbPart = spreadSheet.WorkbookPart;

                // Find the sheet with the supplied name, and then use that 
                // Sheet object to retrieve a reference to the first worksheet.
                Sheet theSheet = wbPart.Workbook.Descendants<Sheet>().
                  Where(s => s.Name == sheetName).FirstOrDefault();

                // Throw an exception if there is no sheet.
                if (theSheet == null)
                {
                    // Add a blank WorksheetPart.
                    WorksheetPart newWorksheetPart = spreadSheet.WorkbookPart.AddNewPart<WorksheetPart>();
                    newWorksheetPart.Worksheet = new Worksheet(new SheetData());

                    Sheets sheets = spreadSheet.WorkbookPart.Workbook.GetFirstChild<Sheets>();
                    string relationshipId = spreadSheet.WorkbookPart.GetIdOfPart(newWorksheetPart);

                    // Get a unique ID for the new worksheet.
                    uint sheetId = 1;
                    if (sheets.Elements<Sheet>().Count() > 0)
                    {
                        sheetId = sheets.Elements<Sheet>().Select(s => s.SheetId.Value).Max() + 1;
                    }

                    // Give the new worksheet a name.
                    username += sheetId;

                    // Append the new worksheet and associate it with the workbook.
                    theSheet = new Sheet() { Id = relationshipId, SheetId = sheetId, Name = username };
                    sheets.Append(theSheet);
                    //throw new ArgumentException("sheetName");
                }
                Console.WriteLine(username);
                Console.WriteLine(theSheet.SheetId.Value);
                // Retrieve a reference to the worksheet part.
                WorksheetPart worksheetPart =
                    (WorksheetPart)(wbPart.GetPartById(theSheet.Id));

                // Insert a new worksheet.
                //WorksheetPart worksheetPart = InsertWorksheet(spreadSheet.WorkbookPart);

                // Insert cell A1 into the new worksheet.
                /*Cell cell = InsertCellInWorksheet(column, 2, worksheetPart);

                // Set the value of cell A1.
                cell.CellValue = new CellValue(index.ToString());
                cell.DataType = new EnumValue<CellValues>(CellValues.SharedString);*/
                Console.WriteLine(column);

                for (uint i = 0; i < data.Length; i++)
                {
                    // Insert cell A1 into the new worksheet.
                    Cell cell = InsertCellInWorksheet(column, i + 1, worksheetPart);
                    //Cell cell = InsertCellInWorksheet("AA", i + 1, worksheetPart);

                    // Set the value of cell A1.
                    cell.CellValue = new CellValue(dindex[i].ToString());
                    //cell.InlineString = new InlineString() { Text = new Text(dindex[i].ToString()) };
                    cell.DataType = new EnumValue<CellValues>(CellValues.SharedString);
                    worksheetPart.Worksheet.Save();
                }

                // Save the new worksheet.
                worksheetPart.Worksheet.Save();
            }
        }
        private static int InsertSharedStringItem(string text, SharedStringTablePart shareStringPart)
        {
            // If the part does not contain a SharedStringTable, create one.
            if (shareStringPart.SharedStringTable == null)
            {
                shareStringPart.SharedStringTable = new SharedStringTable();
            }

            int i = 0;

            // Iterate through all the items in the SharedStringTable. If the text already exists, return its index.
            foreach (SharedStringItem item in shareStringPart.SharedStringTable.Elements<SharedStringItem>())
            {
                if (item.InnerText == text)
                {
                    return i;
                }

                i++;
            }

            // The text does not exist in the part. Create the SharedStringItem and return its index.
            shareStringPart.SharedStringTable.AppendChild(new SharedStringItem(new DocumentFormat.OpenXml.Spreadsheet.Text(text)));
            shareStringPart.SharedStringTable.Save();

            return i;
        }
        private static WorksheetPart InsertWorksheet(WorkbookPart workbookPart)
        {
            // Add a new worksheet part to the workbook.
            WorksheetPart newWorksheetPart = workbookPart.AddNewPart<WorksheetPart>();
            newWorksheetPart.Worksheet = new Worksheet(new SheetData());
            newWorksheetPart.Worksheet.Save();

            Sheets sheets = workbookPart.Workbook.GetFirstChild<Sheets>();
            string relationshipId = workbookPart.GetIdOfPart(newWorksheetPart);

            // Get a unique ID for the new sheet.
            uint sheetId = 1;
            if (sheets.Elements<Sheet>().Count() > 0)
            {
                sheetId = sheets.Elements<Sheet>().Select(s => s.SheetId.Value).Max() + 1;
            }

            string sheetName = "Sheet" + sheetId;

            // Append the new worksheet and associate it with the workbook.
            Sheet sheet = new Sheet() { Id = relationshipId, SheetId = sheetId, Name = sheetName };
            sheets.Append(sheet);
            workbookPart.Workbook.Save();

            return newWorksheetPart;
        }
        private static Cell InsertCellInWorksheet(string columnName, uint rowIndex, WorksheetPart worksheetPart)
        {
            Worksheet worksheet = worksheetPart.Worksheet;
            SheetData sheetData = worksheet.GetFirstChild<SheetData>();
            string cellReference = columnName + rowIndex;

            // If the worksheet does not contain a row with the specified row index, insert one.
            Row row;
            if (sheetData.Elements<Row>().Where(r => r.RowIndex == rowIndex).Count() != 0)
            {
                row = sheetData.Elements<Row>().Where(r => r.RowIndex == rowIndex).First();
            }
            else
            {
                row = new Row() { RowIndex = rowIndex };
                sheetData.Append(row);
            }

            // If there is not a cell with the specified column name, insert one.  
            if (row.Elements<Cell>().Where(c => c.CellReference.Value == columnName + rowIndex).Count() > 0)
            {
                return row.Elements<Cell>().Where(c => c.CellReference.Value == cellReference).First();
            }
            else
            {
                //Console.WriteLine("Fit");
                // Cells must be in sequential order according to CellReference. Determine where to insert the new cell.
                Cell refCell = null;
                foreach (Cell cell in row.Elements<Cell>())
                {
                    if (columnName.Length == 2 && Char.IsNumber((char)cell.CellReference.Value[1]))
                    {
                        break;
                    }
                    if (string.Compare(cell.CellReference.Value, cellReference, true) > 0)
                    {
                        Console.WriteLine(cell.CellReference.Value);
                        refCell = cell;
                        break;
                    }
                }

                Cell newCell = new Cell() { CellReference = cellReference };
                row.InsertBefore(newCell, refCell);

                worksheet.Save();
                return newCell;
            }
        }

        public static string Gen_Random_Num_Easy(Random rnd)
        {
            int p = rnd.Next(3, 9);
            string s1 = p.ToString() + rnd.Next(100000000, 999999999).ToString();
            string s2 = rnd.Next(1, p - 1).ToString() + rnd.Next(100000000, 999999999).ToString();
            int[] s = new int[30];
            for (int i = 0; i < 10; i++)
            {
                if (s1[i] >= s2[i])
                {
                    s[i] = s1[i] - '0';
                    s[10 + i] = s2[i] - '0';
                    s[20 + i] = s1[i] - s2[i];
                }
                else
                {
                    s[i] = s2[i] - '0';
                    s[10 + i] = s1[i] - '0';
                    s[20 + i] = s2[i] - s1[i];
                }
            }
            var builder = new StringBuilder();
            Array.ForEach(s, x => builder.Append(x));
            var res = builder.ToString();
            return res;
        }
        public static string Gen_Random_Num_Hard(Random rnd)
        {
            int p = rnd.Next(3, 9);
            string p2 = rnd.Next(1, p - 1).ToString()
                + rnd.Next(1, 9).ToString()
                + rnd.Next(1, 9).ToString()
                + rnd.Next(1, 9).ToString()
                + rnd.Next(1, 9).ToString()
                + rnd.Next(1, 9).ToString()
                + rnd.Next(1, 9).ToString()
                + rnd.Next(0, 9).ToString()
                + rnd.Next(0, 9).ToString()
                + rnd.Next(0, 9).ToString();
            string p1 = p.ToString()
                + rnd.Next(0, p2[1] - '0' - 1).ToString()
                + rnd.Next(0, p2[2] - '0' - 1).ToString()
                + rnd.Next(0, p2[3] - '0' - 1).ToString()
                + rnd.Next(0, p2[4] - '0' - 1).ToString()
                + rnd.Next(0, p2[5] - '0' - 1).ToString()
                + rnd.Next(0, p2[6] - '0' - 1).ToString()
                + rnd.Next(p2[7] - '0', 9).ToString()
                + rnd.Next(p2[8] - '0', 9).ToString()
                + rnd.Next(p2[9] - '0', 9).ToString();
            int[] s = new int[30];
            for (int i = 0; i < 10; i++)
            {
                s[i] = p1[i] - '0';
                s[10 + i] = p2[i] - '0';
            }
            Console.WriteLine(p1);
            Console.WriteLine(p2);
            for (int i = 1; i < 10; i++)
            {
                int tmp1 = s[i];
                int tmp2 = s[10 + i];
                int r = rnd.Next(i, 9);
                s[i] = s[r];
                s[10 + i] = s[10 + r];
                s[r] = tmp1;
                s[10 + r] = tmp2;
            }
            for (int i = 9; i > 0; i--)
            {
                s[20 + i] += s[i] - s[10 + i];
                if (s[20 + i] < 0)
                {
                    s[20 + i] += 10;
                    s[20 + i - 1] -= 1;
                }
            }
            s[20] += s[0] - s[10];
            var builder = new StringBuilder();
            Array.ForEach(s, x => builder.Append(x));
            var res = builder.ToString();
            return res;
        }

        private void Sequence(Random rnd)
        {
            trial[0] = 5;
            trial[1] = 6;
            trial[2] = 5;
            trial[3] = 6;
            trial[4] = 5;
            trial[5] = 6;
            //trial[6] = 1;
            //trial[7] = 2;
            //trial[8] = 3;
            //trial[9] = 4;
            string str = "111111" + "222222" + "333333" + "444444";
            str = Shuffle(str, rnd);
            for (int i = 0; i < str.Length; i++)
            {
                trial[6 + i] = str[i] - '0';
            }
            //foreach (var item in trial)
            //  Console.Write(item.ToString() + " ");
            //Console.WriteLine(Convert.ToString(trial));
        }
        public void SubControl()
        {
            mTextboxList.Add(maskedTextBox30);
            mTextboxList.Add(maskedTextBox29);
            mTextboxList.Add(maskedTextBox28);
            mTextboxList.Add(maskedTextBox27);
            mTextboxList.Add(maskedTextBox26);
            mTextboxList.Add(maskedTextBox25);
            mTextboxList.Add(maskedTextBox24);
            mTextboxList.Add(maskedTextBox23);
            mTextboxList.Add(maskedTextBox22);
            mTextboxList.Add(maskedTextBox21);
            maskedTextBox30.ContextMenu = new ContextMenu();
            maskedTextBox29.ContextMenu = new ContextMenu();
            maskedTextBox28.ContextMenu = new ContextMenu();
            maskedTextBox27.ContextMenu = new ContextMenu();
            maskedTextBox26.ContextMenu = new ContextMenu();
            maskedTextBox25.ContextMenu = new ContextMenu();
            maskedTextBox24.ContextMenu = new ContextMenu();
            maskedTextBox23.ContextMenu = new ContextMenu();
            maskedTextBox22.ContextMenu = new ContextMenu();
            maskedTextBox21.ContextMenu = new ContextMenu();
            sTextboxList.Add(maskedTextBox20);
            sTextboxList.Add(maskedTextBox19);
            sTextboxList.Add(maskedTextBox18);
            sTextboxList.Add(maskedTextBox17);
            sTextboxList.Add(maskedTextBox16);
            sTextboxList.Add(maskedTextBox15);
            sTextboxList.Add(maskedTextBox14);
            sTextboxList.Add(maskedTextBox13);
            sTextboxList.Add(maskedTextBox12);
            sTextboxList.Add(maskedTextBox11);
            sTextboxList.Add(maskedTextBox10);
            sTextboxList.Add(maskedTextBox9);
            sTextboxList.Add(maskedTextBox8);
            sTextboxList.Add(maskedTextBox7);
            sTextboxList.Add(maskedTextBox6);
            sTextboxList.Add(maskedTextBox5);
            sTextboxList.Add(maskedTextBox4);
            sTextboxList.Add(maskedTextBox3);
            sTextboxList.Add(maskedTextBox2);
            sTextboxList.Add(maskedTextBox1);
        }
        private void String1(string operand)
        {
            maskedTextBox1.Text = operand[0].ToString();
            maskedTextBox2.Text = operand[1].ToString();
            maskedTextBox3.Text = operand[2].ToString();
            maskedTextBox4.Text = operand[3].ToString();
            maskedTextBox5.Text = operand[4].ToString();
            maskedTextBox6.Text = operand[5].ToString();
            maskedTextBox7.Text = operand[6].ToString();
            maskedTextBox8.Text = operand[7].ToString();
            maskedTextBox9.Text = operand[8].ToString();
            maskedTextBox10.Text = operand[9].ToString();
        }
        private void String2(string operand)
        {
            maskedTextBox11.Text = operand[0].ToString();
            maskedTextBox12.Text = operand[1].ToString();
            maskedTextBox13.Text = operand[2].ToString();
            maskedTextBox14.Text = operand[3].ToString();
            maskedTextBox15.Text = operand[4].ToString();
            maskedTextBox16.Text = operand[5].ToString();
            maskedTextBox17.Text = operand[6].ToString();
            maskedTextBox18.Text = operand[7].ToString();
            maskedTextBox19.Text = operand[8].ToString();
            maskedTextBox20.Text = operand[9].ToString();
        }
        private void String3(string operand)
        {
            maskedTextBox31.Text = operand[0].ToString();
            maskedTextBox32.Text = operand[1].ToString();
            maskedTextBox33.Text = operand[2].ToString();
            maskedTextBox34.Text = operand[3].ToString();
            maskedTextBox35.Text = operand[4].ToString();
            maskedTextBox36.Text = operand[5].ToString();
            maskedTextBox37.Text = operand[6].ToString();
            maskedTextBox38.Text = operand[7].ToString();
            maskedTextBox39.Text = operand[8].ToString();
            maskedTextBox40.Text = operand[9].ToString();
        }

        private void Subtract(Random rnd)
        {
            switch (version)
            {
                case 1:
                case 2:
                case 5:
                    subDisplay = Gen_Random_Num_Easy(rnd);
                    break;
                case 3:
                case 4:
                case 6:
                    subDisplay = Gen_Random_Num_Hard(rnd);
                    break;
                default:
                    throw new System.InvalidOperationException("Impossible");
            }
            String1(subDisplay.Substring(0, 10));
            String2(subDisplay.Substring(10, 10));
            String3(subDisplay.Substring(20, 10));
            //maskedTextBox30.Select();
            mTextboxList[0].Select();
        }
        private void TextEntry(Random rnd)
        {
            textDisplay = GetCellValue(@"R.xlsx", "words21", "A" + rnd.Next(1, 35867));
            switch (version)
            {
                case 1:
                case 3:
                case 6:
                    textDisplay = Shuffle(textDisplay, rnd);
                    //textBox1.Text = textDisplay[0].ToString();
                    stringText.Text = textDisplay[0].ToString();
                    break;
                case 2:
                case 4:
                case 5:
                    //textBox1.Text = textDisplay.ToString();
                    stringText.Text = textDisplay.ToString();
                    break;
                default:
                    throw new System.InvalidOperationException("Impossible");
            }
            textBox3.Text = textDisplay;
            //InsertText(@"C:\Users\Ganesh\Desktop\w.xlsx", "Sheet1", "Ihello");
            //string value = GetCellValue(@"C:\Users\Ganesh\Desktop\w.xlsx", "words", "A" + rnd.Next(1, 7));
            //value = GetCellValue(@"w.xlsx", "words", "A" + rnd.Next(1, 7));
        }

        public static string Shuffle(string str, Random rng)
        {
            char[] array = str.ToCharArray();
            //Random rng = new Random();
            int n = array.Length;
            while (n > 1)
            {
                n--;
                int k = rng.Next(0, n + 1);
                var value = array[k];
                array[k] = array[n];
                array[n] = value;
            }
            return new string(array);
        }
        private int Compare_Text(string s1, string s2)
        {
            int sim = 0;
            for (int i = 0; i < 10; i++)
            {
                if (s1[i] == s2[i])
                {
                    sim++;
                }
            }
            return sim;
        }
        private int Compare_Sub(string s1, string s2)
        {
            int sim = 0;
            for (int i = 0; i < 10; i++)
            {
                if (s1[i] == s2[9 - i])
                {
                    sim++;
                }
            }
            return sim;
        }
        public static void DisplayTimerProperties()
        {
            //Stopwatch stopWatch = new Stopwatch();
            // Display the timer frequency and resolution. 
            if (Stopwatch.IsHighResolution)
            {
                Console.WriteLine("Operations timed using the system's high-resolution performance counter.");
            }
            else
            {
                Console.WriteLine("Operations timed using the DateTime class.");
            }

            long frequency = Stopwatch.Frequency;
            Console.WriteLine("  Timer frequency in ticks per second = {0}",
                frequency);
            long nanosecPerTick = (1000L * 1000L * 1000L) / frequency;
            Console.WriteLine("  Timer is accurate within {0} nanoseconds",
                nanosecPerTick);
        }
    }
}
